@@ -2,12 +2,11 @@ from abc import ABC
 from dataclasses import dataclass
 from typing import Iterable, Optional, TextIO, Type
 
-from rdflib import URIRef
-from urlpath import URL
-
-from iolanta.models import LDContext, Quad, LDDocument
+from iolanta.models import LDContext, LDDocument, Quad
 from iolanta.namespaces import PYTHON
 from iolanta.parsers.base import Parser
+from rdflib import URIRef
+from urlpath import URL
 
 
 def term_for_python_class(cls: type) -> URIRef:
