@@ -2,7 +2,7 @@ from abc import ABC
 from dataclasses import dataclass, field
 from typing import Iterable, Optional, TextIO
 
-from iolanta.models import LDContext, Quad, ContextAliases, LDDocument
+from iolanta.models import ContextAliases, LDContext, LDDocument, Quad
 from rdflib import URIRef
 from urlpath import URL
 
