@@ -1,13 +1,12 @@
 import json
 from functools import partial
 from itertools import starmap
-from typing import TextIO, Optional, Iterable
+from typing import Iterable, Optional, TextIO
 
-from rdflib import URIRef, Graph
-
-from iolanta.models import LDDocument, LDContext, Quad, Triple
+from iolanta.models import LDContext, LDDocument, Quad, Triple
 from iolanta.parsers.base import Parser
 from iolanta.reformat_blank_nodes import reformat_blank_nodes
+from rdflib import Graph, URIRef
 
 
 class JSON(Parser):
