@@ -1,11 +1,10 @@
 from pathlib import Path
-from typing import Type, Iterable
-
-from rdflib import URIRef
-from urlpath import URL
+from typing import Iterable, Type
 
 from iolanta.loaders.local_file import Loader, LocalFile
-from iolanta.models import LDDocument, Quad, LDContext
+from iolanta.models import LDContext, LDDocument, Quad
+from rdflib import URIRef
+from urlpath import URL
 
 
 def choose_loader_by_url(url: URL) -> Type[Loader]:
