@@ -1,9 +1,9 @@
 from dataclasses import dataclass
-from typing import Dict, List, Union, Optional
+from typing import Dict, List, Optional, Union
 
 from rdflib import Graph
 from rdflib.plugins.sparql.processor import SPARQLResult
-from rdflib.term import Node, Variable, Identifier
+from rdflib.term import Identifier, Node, Variable
 
 SelectRow = Dict[str, Node]
 
