@@ -1,9 +1,8 @@
 from dominate.tags import a
-from more_itertools import first
-
 from iolanta.facets.errors import PageNotFound
+from more_itertools import first
 from octadocs.octiron import Octiron
-from rdflib.term import Node, Literal
+from rdflib.term import Literal, Node
 
 
 def default(octiron: Octiron, iri: Node) -> str:
