@@ -6,22 +6,17 @@ from enum import Enum, auto
 from functools import reduce
 from pathlib import Path
 from types import MappingProxyType
-from typing import Dict, Iterable, Optional, Type, Any
+from typing import Any, Dict, Iterable, Optional, Type
 
 import rdflib
-from rdflib import ConjunctiveGraph
-from rdflib.plugins.sparql.processor import SPARQLResult
-from typer import Typer
-from urlpath import URL
-
-from iolanta.loaders.local_file import ParserNotFound, IsAContext
+from iolanta.context import merge
+from iolanta.loaders.local_file import IsAContext, ParserNotFound
 from iolanta.models import LDContext
 from iolanta.namespaces import LOCAL
 from iolanta.shortcuts import as_quad_stream
 from ldflex import LDFlex
 from octadocs.conversions import triples_to_quads
 from octadocs.describe_documentation_page import describe_documentation_page
-from iolanta.context import merge
 from octadocs.octiron.context_loaders import (
     context_from_json,
     context_from_yaml,
@@ -30,15 +25,15 @@ from octadocs.octiron.inference import (
     apply_inference_owlrl,
     apply_inference_sparql,
 )
-from octadocs.octiron.plugins import (
-    Loader,
-    MarkdownLoader,
-    YAMLLoader,
-)
+from octadocs.octiron.plugins import Loader, MarkdownLoader, YAMLLoader
 from octadocs.query import _format_query_bindings
-from octadocs.types import Context, QueryResult
 from octadocs.types import DEFAULT_NAMESPACES
 from octadocs.types import LOCAL as local
+from octadocs.types import Context, QueryResult
+from rdflib import ConjunctiveGraph
+from rdflib.plugins.sparql.processor import SPARQLResult
+from typer import Typer
+from urlpath import URL
 
 if sys.version_info >= (3, 8):
     from functools import cached_property  # noqa
