@@ -1,9 +1,9 @@
 from copy import deepcopy
 from dataclasses import dataclass
-from typing import Dict, Any
+from typing import Any, Dict
 
-from iolanta.models import LDContext
 from iolanta.context import merge
+from iolanta.models import LDContext
 from octadocs.pyld_document_loaders.base import DocumentLoader
 from octadocs.pyld_document_loaders.models import JsonLDDocument
 
