@@ -1,14 +1,13 @@
 from pathlib import Path
-from typing import Dict, Any
+from typing import Any, Dict
 
 from mkdocs.plugins import BasePlugin
 from mkdocs.structure.pages import Page
 from octadocs.octiron.context_loaders import context_from_yaml
 from octadocs.plugin import cached_octiron
-from rdflib import Namespace, URIRef
-
 from octadocs_adr.macros import DecisionContext
 from octadocs_adr.models import ADR
+from rdflib import Namespace, URIRef
 
 
 class ADRPlugin(BasePlugin):
